#[non_exhaustive]pub enum Incoming {
Call(Call),
Signal(SignalMessage),
}Expand description
A message which arrived on the connection and is not a reply.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Call(Call)
A method call which is expected to be replied to.
Signal(SignalMessage)
A signal, which is never replied to.